@@ -1,9 +1,7 @@
-package Kinghost::Painel;
+﻿package Kinghost::Painel;
 
         use strict;
 	use warnings 'all';
-	use Win32::ASP;
-	use Win32::OLE;
 	use WWW::Mechanize;
         use HTML::TreeBuilder::XPath;
         use HTML::Entities;
@@ -21,7 +19,7 @@ package Kinghost::Painel;
             };
             
             $statusLogin = 0;
-            $entitieschars = '';
+            $entitieschars = 'ÁÍÓÚÉÄÏÖÜËÀÌÒÙÈÃÕÂÎÔÛÊáíóúéäïöüëàìòùèãõâîôûêÇç';
             $mech = WWW::Mechanize->new;
             
             bless $self, $class;           
@@ -495,8 +493,8 @@ version 0.002
 
 
     # Novo Cliente
-    my $empresa = "Joo25";
-    my $nome = "Jos Joo25";
+    my $empresa = "João25";
+    my $nome = "José João25";
     my $tipoPessoa = "F"; # F - J - I(ignorar)
     my $cpfcnpj = "000.000.000-00"; # CPF ou CNPJ
     my $email = 'xxxxxgg@gmail.com';
@@ -512,7 +510,7 @@ version 0.002
     print $painel->novoCliente($empresa, $nome, $tipoPessoa, $cpfcnpj, $email, $emailcobranca, $senha, $senhaConfimacao, $telefone, $fax, $cep, $endereco, $cidade, $estado);
 
 
-    # Novo Domnio
+    # Novo Domínio
     my $plano = "45198";
     my $dominio = "topjeca.com.br";
     my $cliente = "107645";
@@ -533,7 +531,7 @@ version 0.002
 
 =head2 logar
 
-Loga no painel de controle. Este mtodo dever ser usado chamado antes de qualquer outro mtodo. Ativa flag $statusLogin.
+Loga no painel de controle. Este método deverá ser usado chamado antes de qualquer outro método. Ativa flag $statusLogin.
 
     my $status_login = $painel->logar($email, $senha);
 
@@ -549,7 +547,7 @@ Cadastra novo cliente
 
 Return JSON
 
-    {"nome":"Jos Joo25","resposta":"registrado","status":"sucesso","codigo":"107630"}
+    {"nome":"José João25","resposta":"registrado","status":"sucesso","codigo":"107630"}
     {"resposta":"E-mail em uso","status":"erro"}
     {"resposta":"efetue login primeiro","status":"erro"}
 
@@ -577,12 +575,12 @@ Return JSON
 
 =head1 AUTHORS
 
-Jos Eduardo Perotta de Almeida, C<< eduardo at web2solutions.com.br >>
+José Eduardo Perotta de Almeida, C<< eduardo at web2solutions.com.br >>
 
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Jos Eduardo Perotta de Almeida.
+Copyright 2012 José Eduardo Perotta de Almeida.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
